@@ -163,7 +163,7 @@ def _stdout_handler():
 
 def _minimal_stdout_handler():
     _date_format = DATEFORMAT_DEV
-    formatter = CustomFormatter(fmt='{asctime} ||--> {message}', datefmt=_date_format, style='{')
+    formatter = CustomFormatter(fmt='{asctime} |{levelname:^11}||--> {message}', datefmt=_date_format, style='{')
     # formatter = logging.Formatter(fmt='[{asctime}][{levelname:^7}][{name:<30}][{funcName:^25}] --> {message}', datefmt=_date_format, style='{')
     handler = logging.StreamHandler()
     handler.setFormatter(formatter)
